# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: InfoConfig.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ighap_bot.proto import Request_pb2 as Request__pb2
from ighap_bot.proto import Response_pb2 as Response__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='InfoConfig.proto',
  package='proto',
  syntax='proto3',
  serialized_pb=_b('\n\x10InfoConfig.proto\x12\x05proto\x1a\rRequest.proto\x1a\x0eResponse.proto\"-\n\nInfoConfig\x12\x1f\n\x07request\x18\x01 \x01(\x0b\x32\x0e.proto.Request\"\xb6\x04\n\x12InfoConfigResponse\x12!\n\x08response\x18\x01 \x01(\x0b\x32\x0f.proto.Response\x12\x12\n\ndebug_mode\x18\x02 \x01(\x08\x12\x17\n\x0f\x64\x65\x66\x61ult_timeout\x18\x03 \x01(\r\x12\x15\n\roptimize_mode\x18\x04 \x01(\x08\x12\x15\n\rmax_file_size\x18\x05 \x01(\x04\x12\x1a\n\x12\x63\x61ption_length_max\x18\x06 \x01(\x04\x12\x1a\n\x12message_length_max\x18\x07 \x01(\x04\x12\x1e\n\x16group_add_member_limit\x18\x08 \x01(\r\x12 \n\x18\x63hannel_add_member_limit\x18\t \x01(\r\x12*\n\rmicro_service\x18\n \x03(\x0b\x32\x13.proto.MicroService\x12\x34\n\x08\x64\x65\x62ugger\x18\x0b \x01(\x0e\x32\".proto.InfoConfigResponse.Debugger\x12\x10\n\x08\x62\x61se_url\x18\x0c \x01(\t\x12\x18\n\x10show_advertising\x18\r \x01(\x08\x12\x31\n\ndefaultTab\x18\x0e \x01(\x0e\x32\x1d.proto.InfoConfigResponse.Tab\"\'\n\x08\x44\x65\x62ugger\x12\x0f\n\x0b\x43RASHLYTICS\x10\x00\x12\n\n\x06SENTRY\x10\x01\">\n\x03Tab\x12\x0b\n\x07\x43ONTACT\x10\x00\x12\x08\n\x04\x43\x41LL\x10\x01\x12\x08\n\x04\x43HAT\x10\x02\x12\t\n\x05ILAND\x10\x03\x12\x0b\n\x07SETTING\x10\x04\"w\n\x0cMicroService\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x30\n\x04type\x18\x02 \x01(\x0e\x32\".proto.MicroService.ConnectionType\"\'\n\x0e\x43onnectionType\x12\t\n\x05HTTPS\x10\x00\x12\n\n\x06SOCKET\x10\x01\x42!\n\x0enet.iGap.protoB\x0fProtoInfoConfigb\x06proto3')
  ,
  dependencies=[Request__pb2.DESCRIPTOR,Response__pb2.DESCRIPTOR,])
_sym_db.RegisterFileDescriptor(DESCRIPTOR)



_INFOCONFIGRESPONSE_DEBUGGER = _descriptor.EnumDescriptor(
  name='Debugger',
  full_name='proto.InfoConfigResponse.Debugger',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='CRASHLYTICS', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SENTRY', index=1, number=1,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=569,
  serialized_end=608,
)
_sym_db.RegisterEnumDescriptor(_INFOCONFIGRESPONSE_DEBUGGER)

_INFOCONFIGRESPONSE_TAB = _descriptor.EnumDescriptor(
  name='Tab',
  full_name='proto.InfoConfigResponse.Tab',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='CONTACT', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CALL', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CHAT', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ILAND', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SETTING', index=4, number=4,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=610,
  serialized_end=672,
)
_sym_db.RegisterEnumDescriptor(_INFOCONFIGRESPONSE_TAB)

_MICROSERVICE_CONNECTIONTYPE = _descriptor.EnumDescriptor(
  name='ConnectionType',
  full_name='proto.MicroService.ConnectionType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='HTTPS', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SOCKET', index=1, number=1,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=754,
  serialized_end=793,
)
_sym_db.RegisterEnumDescriptor(_MICROSERVICE_CONNECTIONTYPE)


_INFOCONFIG = _descriptor.Descriptor(
  name='InfoConfig',
  full_name='proto.InfoConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='request', full_name='proto.InfoConfig.request', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=58,
  serialized_end=103,
)


_INFOCONFIGRESPONSE = _descriptor.Descriptor(
  name='InfoConfigResponse',
  full_name='proto.InfoConfigResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='response', full_name='proto.InfoConfigResponse.response', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='debug_mode', full_name='proto.InfoConfigResponse.debug_mode', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='default_timeout', full_name='proto.InfoConfigResponse.default_timeout', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='optimize_mode', full_name='proto.InfoConfigResponse.optimize_mode', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='max_file_size', full_name='proto.InfoConfigResponse.max_file_size', index=4,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='caption_length_max', full_name='proto.InfoConfigResponse.caption_length_max', index=5,
      number=6, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='message_length_max', full_name='proto.InfoConfigResponse.message_length_max', index=6,
      number=7, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='group_add_member_limit', full_name='proto.InfoConfigResponse.group_add_member_limit', index=7,
      number=8, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='channel_add_member_limit', full_name='proto.InfoConfigResponse.channel_add_member_limit', index=8,
      number=9, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='micro_service', full_name='proto.InfoConfigResponse.micro_service', index=9,
      number=10, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='debugger', full_name='proto.InfoConfigResponse.debugger', index=10,
      number=11, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='base_url', full_name='proto.InfoConfigResponse.base_url', index=11,
      number=12, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='show_advertising', full_name='proto.InfoConfigResponse.show_advertising', index=12,
      number=13, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='defaultTab', full_name='proto.InfoConfigResponse.defaultTab', index=13,
      number=14, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _INFOCONFIGRESPONSE_DEBUGGER,
    _INFOCONFIGRESPONSE_TAB,
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=106,
  serialized_end=672,
)


_MICROSERVICE = _descriptor.Descriptor(
  name='MicroService',
  full_name='proto.MicroService',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='proto.MicroService.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='type', full_name='proto.MicroService.type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _MICROSERVICE_CONNECTIONTYPE,
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=674,
  serialized_end=793,
)

_INFOCONFIG.fields_by_name['request'].message_type = Request__pb2._REQUEST
_INFOCONFIGRESPONSE.fields_by_name['response'].message_type = Response__pb2._RESPONSE
_INFOCONFIGRESPONSE.fields_by_name['micro_service'].message_type = _MICROSERVICE
_INFOCONFIGRESPONSE.fields_by_name['debugger'].enum_type = _INFOCONFIGRESPONSE_DEBUGGER
_INFOCONFIGRESPONSE.fields_by_name['defaultTab'].enum_type = _INFOCONFIGRESPONSE_TAB
_INFOCONFIGRESPONSE_DEBUGGER.containing_type = _INFOCONFIGRESPONSE
_INFOCONFIGRESPONSE_TAB.containing_type = _INFOCONFIGRESPONSE
_MICROSERVICE.fields_by_name['type'].enum_type = _MICROSERVICE_CONNECTIONTYPE
_MICROSERVICE_CONNECTIONTYPE.containing_type = _MICROSERVICE
DESCRIPTOR.message_types_by_name['InfoConfig'] = _INFOCONFIG
DESCRIPTOR.message_types_by_name['InfoConfigResponse'] = _INFOCONFIGRESPONSE
DESCRIPTOR.message_types_by_name['MicroService'] = _MICROSERVICE

InfoConfig = _reflection.GeneratedProtocolMessageType('InfoConfig', (_message.Message,), dict(
  DESCRIPTOR = _INFOCONFIG,
  __module__ = 'InfoConfig_pb2'
  # @@protoc_insertion_point(class_scope:proto.InfoConfig)
  ))
_sym_db.RegisterMessage(InfoConfig)

InfoConfigResponse = _reflection.GeneratedProtocolMessageType('InfoConfigResponse', (_message.Message,), dict(
  DESCRIPTOR = _INFOCONFIGRESPONSE,
  __module__ = 'InfoConfig_pb2'
  # @@protoc_insertion_point(class_scope:proto.InfoConfigResponse)
  ))
_sym_db.RegisterMessage(InfoConfigResponse)

MicroService = _reflection.GeneratedProtocolMessageType('MicroService', (_message.Message,), dict(
  DESCRIPTOR = _MICROSERVICE,
  __module__ = 'InfoConfig_pb2'
  # @@protoc_insertion_point(class_scope:proto.MicroService)
  ))
_sym_db.RegisterMessage(MicroService)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n\016net.iGap.protoB\017ProtoInfoConfig'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: QrCodeNewDevice.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ighap_bot.proto import Request_pb2 as Request__pb2
from ighap_bot.proto import Response_pb2 as Response__pb2
from ighap_bot.proto import Global_pb2 as Global__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='QrCodeNewDevice.proto',
  package='proto',
  syntax='proto3',
  serialized_pb=_b('\n\x15QrCodeNewDevice.proto\x12\x05proto\x1a\rRequest.proto\x1a\x0eResponse.proto\x1a\x0cGlobal.proto\"\xf5\x01\n\x0fQrCodeNewDevice\x12\x1f\n\x07request\x18\x01 \x01(\x0b\x32\x0e.proto.Request\x12\x10\n\x08\x61pp_name\x18\x02 \x01(\t\x12\x0e\n\x06\x61pp_id\x18\x03 \x01(\r\x12\x19\n\x11\x61pp_build_version\x18\x04 \x01(\r\x12\x13\n\x0b\x61pp_version\x18\x05 \x01(\t\x12!\n\x08platform\x18\x06 \x01(\x0e\x32\x0f.proto.Platform\x12\x18\n\x10platform_version\x18\x07 \x01(\t\x12\x1d\n\x06\x64\x65vice\x18\x08 \x01(\x0e\x32\r.proto.Device\x12\x13\n\x0b\x64\x65vice_name\x18\t \x01(\t\"h\n\x17QrCodeNewDeviceResponse\x12!\n\x08response\x18\x01 \x01(\x0b\x32\x0f.proto.Response\x12\x15\n\rqr_code_image\x18\x02 \x01(\x0c\x12\x13\n\x0b\x65xpire_time\x18\x03 \x01(\rB&\n\x0enet.iGap.protoB\x14ProtoQrCodeNewDeviceb\x06proto3')
  ,
  dependencies=[Request__pb2.DESCRIPTOR,Response__pb2.DESCRIPTOR,Global__pb2.DESCRIPTOR,])
_sym_db.RegisterFileDescriptor(DESCRIPTOR)




_QRCODENEWDEVICE = _descriptor.Descriptor(
  name='QrCodeNewDevice',
  full_name='proto.QrCodeNewDevice',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='request', full_name='proto.QrCodeNewDevice.request', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='app_name', full_name='proto.QrCodeNewDevice.app_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='app_id', full_name='proto.QrCodeNewDevice.app_id', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='app_build_version', full_name='proto.QrCodeNewDevice.app_build_version', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='app_version', full_name='proto.QrCodeNewDevice.app_version', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='platform', full_name='proto.QrCodeNewDevice.platform', index=5,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='platform_version', full_name='proto.QrCodeNewDevice.platform_version', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='device', full_name='proto.QrCodeNewDevice.device', index=7,
      number=8, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='device_name', full_name='proto.QrCodeNewDevice.device_name', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=78,
  serialized_end=323,
)


_QRCODENEWDEVICERESPONSE = _descriptor.Descriptor(
  name='QrCodeNewDeviceResponse',
  full_name='proto.QrCodeNewDeviceResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='response', full_name='proto.QrCodeNewDeviceResponse.response', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='qr_code_image', full_name='proto.QrCodeNewDeviceResponse.qr_code_image', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='expire_time', full_name='proto.QrCodeNewDeviceResponse.expire_time', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=325,
  serialized_end=429,
)

_QRCODENEWDEVICE.fields_by_name['request'].message_type = Request__pb2._REQUEST
_QRCODENEWDEVICE.fields_by_name['platform'].enum_type = Global__pb2._PLATFORM
_QRCODENEWDEVICE.fields_by_name['device'].enum_type = Global__pb2._DEVICE
_QRCODENEWDEVICERESPONSE.fields_by_name['response'].message_type = Response__pb2._RESPONSE
DESCRIPTOR.message_types_by_name['QrCodeNewDevice'] = _QRCODENEWDEVICE
DESCRIPTOR.message_types_by_name['QrCodeNewDeviceResponse'] = _QRCODENEWDEVICERESPONSE

QrCodeNewDevice = _reflection.GeneratedProtocolMessageType('QrCodeNewDevice', (_message.Message,), dict(
  DESCRIPTOR = _QRCODENEWDEVICE,
  __module__ = 'QrCodeNewDevice_pb2'
  # @@protoc_insertion_point(class_scope:proto.QrCodeNewDevice)
  ))
_sym_db.RegisterMessage(QrCodeNewDevice)

QrCodeNewDeviceResponse = _reflection.GeneratedProtocolMessageType('QrCodeNewDeviceResponse', (_message.Message,), dict(
  DESCRIPTOR = _QRCODENEWDEVICERESPONSE,
  __module__ = 'QrCodeNewDevice_pb2'
  # @@protoc_insertion_point(class_scope:proto.QrCodeNewDeviceResponse)
  ))
_sym_db.RegisterMessage(QrCodeNewDeviceResponse)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n\016net.iGap.protoB\024ProtoQrCodeNewDevice'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ClientGetRoomHistory.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ighap_bot.proto import Request_pb2 as Request__pb2
from ighap_bot.proto import Response_pb2 as Response__pb2
from ighap_bot.proto import Global_pb2 as Global__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='ClientGetRoomHistory.proto',
  package='proto',
  syntax='proto3',
  serialized_pb=_b('\n\x1a\x43lientGetRoomHistory.proto\x12\x05proto\x1a\rRequest.proto\x1a\x0eResponse.proto\x1a\x0cGlobal.proto\"\xca\x01\n\x14\x43lientGetRoomHistory\x12\x1f\n\x07request\x18\x01 \x01(\x0b\x32\x0e.proto.Request\x12\x0f\n\x07room_id\x18\x02 \x01(\x04\x12\x18\n\x10\x66irst_message_id\x18\x03 \x01(\x04\x12\x38\n\tdirection\x18\x04 \x01(\x0e\x32%.proto.ClientGetRoomHistory.Direction\x12\r\n\x05limit\x18\x05 \x01(\r\"\x1d\n\tDirection\x12\x06\n\x02UP\x10\x00\x12\x08\n\x04\x44OWN\x10\x01\"f\n\x1c\x43lientGetRoomHistoryResponse\x12!\n\x08response\x18\x01 \x01(\x0b\x32\x0f.proto.Response\x12#\n\x07message\x18\x02 \x03(\x0b\x32\x12.proto.RoomMessageB+\n\x0enet.iGap.protoB\x19ProtoClientGetRoomHistoryb\x06proto3')
  ,
  dependencies=[Request__pb2.DESCRIPTOR,Response__pb2.DESCRIPTOR,Global__pb2.DESCRIPTOR,])
_sym_db.RegisterFileDescriptor(DESCRIPTOR)



_CLIENTGETROOMHISTORY_DIRECTION = _descriptor.EnumDescriptor(
  name='Direction',
  full_name='proto.ClientGetRoomHistory.Direction',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UP', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOWN', index=1, number=1,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=256,
  serialized_end=285,
)
_sym_db.RegisterEnumDescriptor(_CLIENTGETROOMHISTORY_DIRECTION)


_CLIENTGETROOMHISTORY = _descriptor.Descriptor(
  name='ClientGetRoomHistory',
  full_name='proto.ClientGetRoomHistory',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='request', full_name='proto.ClientGetRoomHistory.request', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='room_id', full_name='proto.ClientGetRoomHistory.room_id', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='first_message_id', full_name='proto.ClientGetRoomHistory.first_message_id', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='direction', full_name='proto.ClientGetRoomHistory.direction', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='limit', full_name='proto.ClientGetRoomHistory.limit', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CLIENTGETROOMHISTORY_DIRECTION,
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=83,
  serialized_end=285,
)


_CLIENTGETROOMHISTORYRESPONSE = _descriptor.Descriptor(
  name='ClientGetRoomHistoryResponse',
  full_name='proto.ClientGetRoomHistoryResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='response', full_name='proto.ClientGetRoomHistoryResponse.response', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='message', full_name='proto.ClientGetRoomHistoryResponse.message', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=287,
  serialized_end=389,
)

_CLIENTGETROOMHISTORY.fields_by_name['request'].message_type = Request__pb2._REQUEST
_CLIENTGETROOMHISTORY.fields_by_name['direction'].enum_type = _CLIENTGETROOMHISTORY_DIRECTION
_CLIENTGETROOMHISTORY_DIRECTION.containing_type = _CLIENTGETROOMHISTORY
_CLIENTGETROOMHISTORYRESPONSE.fields_by_name['response'].message_type = Response__pb2._RESPONSE
_CLIENTGETROOMHISTORYRESPONSE.fields_by_name['message'].message_type = Global__pb2._ROOMMESSAGE
DESCRIPTOR.message_types_by_name['ClientGetRoomHistory'] = _CLIENTGETROOMHISTORY
DESCRIPTOR.message_types_by_name['ClientGetRoomHistoryResponse'] = _CLIENTGETROOMHISTORYRESPONSE

ClientGetRoomHistory = _reflection.GeneratedProtocolMessageType('ClientGetRoomHistory', (_message.Message,), dict(
  DESCRIPTOR = _CLIENTGETROOMHISTORY,
  __module__ = 'ClientGetRoomHistory_pb2'
  # @@protoc_insertion_point(class_scope:proto.ClientGetRoomHistory)
  ))
_sym_db.RegisterMessage(ClientGetRoomHistory)

ClientGetRoomHistoryResponse = _reflection.GeneratedProtocolMessageType('ClientGetRoomHistoryResponse', (_message.Message,), dict(
  DESCRIPTOR = _CLIENTGETROOMHISTORYRESPONSE,
  __module__ = 'ClientGetRoomHistory_pb2'
  # @@protoc_insertion_point(class_scope:proto.ClientGetRoomHistoryResponse)
  ))
_sym_db.RegisterMessage(ClientGetRoomHistoryResponse)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n\016net.iGap.protoB\031ProtoClientGetRoomHistory'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ClientRoomReport.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ighap_bot.proto import Request_pb2 as Request__pb2
from ighap_bot.proto import Response_pb2 as Response__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='ClientRoomReport.proto',
  package='proto',
  syntax='proto3',
  serialized_pb=_b('\n\x16\x43lientRoomReport.proto\x12\x05proto\x1a\rRequest.proto\x1a\x0eResponse.proto\"\xe6\x01\n\x10\x43lientRoomReport\x12\x1f\n\x07request\x18\x01 \x01(\x0b\x32\x0e.proto.Request\x12\x0f\n\x07room_id\x18\x02 \x01(\x04\x12\x12\n\nmessage_id\x18\x03 \x01(\x04\x12.\n\x06reason\x18\x04 \x01(\x0e\x32\x1e.proto.ClientRoomReport.Reason\x12\x13\n\x0b\x64\x65scription\x18\x05 \x01(\t\"G\n\x06Reason\x12\t\n\x05OTHER\x10\x00\x12\x08\n\x04SPAM\x10\x01\x12\x0f\n\x0bPORNOGRAPHY\x10\x02\x12\x0c\n\x08VIOLENCE\x10\x03\x12\t\n\x05\x41\x42USE\x10\x04\"=\n\x18\x43lientRoomReportResponse\x12!\n\x08response\x18\x01 \x01(\x0b\x32\x0f.proto.ResponseB\'\n\x0enet.iGap.protoB\x15ProtoClientRoomReportb\x06proto3')
  ,
  dependencies=[Request__pb2.DESCRIPTOR,Response__pb2.DESCRIPTOR,])
_sym_db.RegisterFileDescriptor(DESCRIPTOR)



_CLIENTROOMREPORT_REASON = _descriptor.EnumDescriptor(
  name='Reason',
  full_name='proto.ClientRoomReport.Reason',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='OTHER', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SPAM', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PORNOGRAPHY', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='VIOLENCE', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ABUSE', index=4, number=4,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=224,
  serialized_end=295,
)
_sym_db.RegisterEnumDescriptor(_CLIENTROOMREPORT_REASON)


_CLIENTROOMREPORT = _descriptor.Descriptor(
  name='ClientRoomReport',
  full_name='proto.ClientRoomReport',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='request', full_name='proto.ClientRoomReport.request', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='room_id', full_name='proto.ClientRoomReport.room_id', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='message_id', full_name='proto.ClientRoomReport.message_id', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='reason', full_name='proto.ClientRoomReport.reason', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='description', full_name='proto.ClientRoomReport.description', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CLIENTROOMREPORT_REASON,
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=65,
  serialized_end=295,
)


_CLIENTROOMREPORTRESPONSE = _descriptor.Descriptor(
  name='ClientRoomReportResponse',
  full_name='proto.ClientRoomReportResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='response', full_name='proto.ClientRoomReportResponse.response', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=297,
  serialized_end=358,
)

_CLIENTROOMREPORT.fields_by_name['request'].message_type = Request__pb2._REQUEST
_CLIENTROOMREPORT.fields_by_name['reason'].enum_type = _CLIENTROOMREPORT_REASON
_CLIENTROOMREPORT_REASON.containing_type = _CLIENTROOMREPORT
_CLIENTROOMREPORTRESPONSE.fields_by_name['response'].message_type = Response__pb2._RESPONSE
DESCRIPTOR.message_types_by_name['ClientRoomReport'] = _CLIENTROOMREPORT
DESCRIPTOR.message_types_by_name['ClientRoomReportResponse'] = _CLIENTROOMREPORTRESPONSE

ClientRoomReport = _reflection.GeneratedProtocolMessageType('ClientRoomReport', (_message.Message,), dict(
  DESCRIPTOR = _CLIENTROOMREPORT,
  __module__ = 'ClientRoomReport_pb2'
  # @@protoc_insertion_point(class_scope:proto.ClientRoomReport)
  ))
_sym_db.RegisterMessage(ClientRoomReport)

ClientRoomReportResponse = _reflection.GeneratedProtocolMessageType('ClientRoomReportResponse', (_message.Message,), dict(
  DESCRIPTOR = _CLIENTROOMREPORTRESPONSE,
  __module__ = 'ClientRoomReport_pb2'
  # @@protoc_insertion_point(class_scope:proto.ClientRoomReportResponse)
  ))
_sym_db.RegisterMessage(ClientRoomReportResponse)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n\016net.iGap.protoB\025ProtoClientRoomReport'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: PushLoginToken.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ighap_bot.proto import Response_pb2 as Response__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='PushLoginToken.proto',
  package='proto',
  syntax='proto3',
  serialized_pb=_b('\n\x14PushLoginToken.proto\x12\x05proto\x1a\x0eResponse.proto\"\x82\x01\n\x16PushLoginTokenResponse\x12!\n\x08response\x18\x01 \x01(\x0b\x32\x0f.proto.Response\x12\x10\n\x08username\x18\x02 \x01(\t\x12\x0f\n\x07user_id\x18\x03 \x01(\x04\x12\x13\n\x0b\x61uthor_hash\x18\x04 \x01(\t\x12\r\n\x05token\x18\x05 \x01(\tB%\n\x0enet.iGap.protoB\x13ProtoPushLoginTokenb\x06proto3')
  ,
  dependencies=[Response__pb2.DESCRIPTOR,])
_sym_db.RegisterFileDescriptor(DESCRIPTOR)




_PUSHLOGINTOKENRESPONSE = _descriptor.Descriptor(
  name='PushLoginTokenResponse',
  full_name='proto.PushLoginTokenResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='response', full_name='proto.PushLoginTokenResponse.response', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='username', full_name='proto.PushLoginTokenResponse.username', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='user_id', full_name='proto.PushLoginTokenResponse.user_id', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='author_hash', full_name='proto.PushLoginTokenResponse.author_hash', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='token', full_name='proto.PushLoginTokenResponse.token', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=48,
  serialized_end=178,
)

_PUSHLOGINTOKENRESPONSE.fields_by_name['response'].message_type = Response__pb2._RESPONSE
DESCRIPTOR.message_types_by_name['PushLoginTokenResponse'] = _PUSHLOGINTOKENRESPONSE

PushLoginTokenResponse = _reflection.GeneratedProtocolMessageType('PushLoginTokenResponse', (_message.Message,), dict(
  DESCRIPTOR = _PUSHLOGINTOKENRESPONSE,
  __module__ = 'PushLoginToken_pb2'
  # @@protoc_insertion_point(class_scope:proto.PushLoginTokenResponse)
  ))
_sym_db.RegisterMessage(PushLoginTokenResponse)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n\016net.iGap.protoB\023ProtoPushLoginToken'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ClientCondition.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ighap_bot.proto import Request_pb2 as Request__pb2
from ighap_bot.proto import Response_pb2 as Response__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='ClientCondition.proto',
  package='proto',
  syntax='proto3',
  serialized_pb=_b('\n\x15\x43lientCondition.proto\x12\x05proto\x1a\rRequest.proto\x1a\x0eResponse.proto\"\xbc\x05\n\x0f\x43lientCondition\x12\x1f\n\x07request\x18\x01 \x01(\x0b\x32\x0e.proto.Request\x12*\n\x05rooms\x18\x02 \x03(\x0b\x32\x1b.proto.ClientCondition.Room\x1a\xdb\x04\n\x04Room\x12\x0f\n\x07room_id\x18\x02 \x01(\x04\x12\x17\n\x0fmessage_version\x18\x03 \x01(\x04\x12\x16\n\x0estatus_version\x18\x04 \x01(\x04\x12\x16\n\x0e\x64\x65lete_version\x18\x05 \x01(\x04\x12\"\n\x1aoffline_deleted_deprecated\x18\x06 \x03(\x04\x12\x41\n\x0eoffline_edited\x18\x07 \x03(\x0b\x32).proto.ClientCondition.Room.OfflineEdited\x12\x14\n\x0coffline_seen\x18\x08 \x03(\x04\x12\x10\n\x08\x63lear_id\x18\t \x01(\x04\x12\x16\n\x0e\x63\x61\x63he_start_id\x18\n \x01(\x04\x12\x14\n\x0c\x63\x61\x63he_end_id\x18\x0b \x01(\x04\x12=\n\x0coffline_mute\x18\x0c \x01(\x0e\x32\'.proto.ClientCondition.Room.OfflineMute\x12\x18\n\x10offline_listened\x18\r \x03(\x04\x12\x43\n\x0foffline_deleted\x18\x0e \x03(\x0b\x32*.proto.ClientCondition.Room.OfflineDeleted\x1a\x34\n\rOfflineEdited\x12\x12\n\nmessage_id\x18\x01 \x01(\x04\x12\x0f\n\x07message\x18\x02 \x01(\t\x1a\x32\n\x0eOfflineDeleted\x12\x12\n\nmessage_id\x18\x01 \x01(\x04\x12\x0c\n\x04\x62oth\x18\x04 \x01(\x08\"4\n\x0bOfflineMute\x12\r\n\tUNCHANGED\x10\x00\x12\t\n\x05MUTED\x10\x01\x12\x0b\n\x07UNMUTED\x10\x02\"<\n\x17\x43lientConditionResponse\x12!\n\x08response\x18\x01 \x01(\x0b\x32\x0f.proto.ResponseB&\n\x0enet.iGap.protoB\x14ProtoClientConditionb\x06proto3')
  ,
  dependencies=[Request__pb2.DESCRIPTOR,Response__pb2.DESCRIPTOR,])
_sym_db.RegisterFileDescriptor(DESCRIPTOR)



_CLIENTCONDITION_ROOM_OFFLINEMUTE = _descriptor.EnumDescriptor(
  name='OfflineMute',
  full_name='proto.ClientCondition.Room.OfflineMute',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNCHANGED', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MUTED', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UNMUTED', index=2, number=2,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=712,
  serialized_end=764,
)
_sym_db.RegisterEnumDescriptor(_CLIENTCONDITION_ROOM_OFFLINEMUTE)


_CLIENTCONDITION_ROOM_OFFLINEEDITED = _descriptor.Descriptor(
  name='OfflineEdited',
  full_name='proto.ClientCondition.Room.OfflineEdited',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='message_id', full_name='proto.ClientCondition.Room.OfflineEdited.message_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='message', full_name='proto.ClientCondition.Room.OfflineEdited.message', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=606,
  serialized_end=658,
)

_CLIENTCONDITION_ROOM_OFFLINEDELETED = _descriptor.Descriptor(
  name='OfflineDeleted',
  full_name='proto.ClientCondition.Room.OfflineDeleted',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='message_id', full_name='proto.ClientCondition.Room.OfflineDeleted.message_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='both', full_name='proto.ClientCondition.Room.OfflineDeleted.both', index=1,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=660,
  serialized_end=710,
)

_CLIENTCONDITION_ROOM = _descriptor.Descriptor(
  name='Room',
  full_name='proto.ClientCondition.Room',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='room_id', full_name='proto.ClientCondition.Room.room_id', index=0,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='message_version', full_name='proto.ClientCondition.Room.message_version', index=1,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='status_version', full_name='proto.ClientCondition.Room.status_version', index=2,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='delete_version', full_name='proto.ClientCondition.Room.delete_version', index=3,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='offline_deleted_deprecated', full_name='proto.ClientCondition.Room.offline_deleted_deprecated', index=4,
      number=6, type=4, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='offline_edited', full_name='proto.ClientCondition.Room.offline_edited', index=5,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='offline_seen', full_name='proto.ClientCondition.Room.offline_seen', index=6,
      number=8, type=4, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='clear_id', full_name='proto.ClientCondition.Room.clear_id', index=7,
      number=9, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='cache_start_id', full_name='proto.ClientCondition.Room.cache_start_id', index=8,
      number=10, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='cache_end_id', full_name='proto.ClientCondition.Room.cache_end_id', index=9,
      number=11, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='offline_mute', full_name='proto.ClientCondition.Room.offline_mute', index=10,
      number=12, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='offline_listened', full_name='proto.ClientCondition.Room.offline_listened', index=11,
      number=13, type=4, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='offline_deleted', full_name='proto.ClientCondition.Room.offline_deleted', index=12,
      number=14, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_CLIENTCONDITION_ROOM_OFFLINEEDITED, _CLIENTCONDITION_ROOM_OFFLINEDELETED, ],
  enum_types=[
    _CLIENTCONDITION_ROOM_OFFLINEMUTE,
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=161,
  serialized_end=764,
)

_CLIENTCONDITION = _descriptor.Descriptor(
  name='ClientCondition',
  full_name='proto.ClientCondition',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='request', full_name='proto.ClientCondition.request', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='rooms', full_name='proto.ClientCondition.rooms', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_CLIENTCONDITION_ROOM, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=64,
  serialized_end=764,
)


_CLIENTCONDITIONRESPONSE = _descriptor.Descriptor(
  name='ClientConditionResponse',
  full_name='proto.ClientConditionResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='response', full_name='proto.ClientConditionResponse.response', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=766,
  serialized_end=826,
)

_CLIENTCONDITION_ROOM_OFFLINEEDITED.containing_type = _CLIENTCONDITION_ROOM
_CLIENTCONDITION_ROOM_OFFLINEDELETED.containing_type = _CLIENTCONDITION_ROOM
_CLIENTCONDITION_ROOM.fields_by_name['offline_edited'].message_type = _CLIENTCONDITION_ROOM_OFFLINEEDITED
_CLIENTCONDITION_ROOM.fields_by_name['offline_mute'].enum_type = _CLIENTCONDITION_ROOM_OFFLINEMUTE
_CLIENTCONDITION_ROOM.fields_by_name['offline_deleted'].message_type = _CLIENTCONDITION_ROOM_OFFLINEDELETED
_CLIENTCONDITION_ROOM.containing_type = _CLIENTCONDITION
_CLIENTCONDITION_ROOM_OFFLINEMUTE.containing_type = _CLIENTCONDITION_ROOM
_CLIENTCONDITION.fields_by_name['request'].message_type = Request__pb2._REQUEST
_CLIENTCONDITION.fields_by_name['rooms'].message_type = _CLIENTCONDITION_ROOM
_CLIENTCONDITIONRESPONSE.fields_by_name['response'].message_type = Response__pb2._RESPONSE
DESCRIPTOR.message_types_by_name['ClientCondition'] = _CLIENTCONDITION
DESCRIPTOR.message_types_by_name['ClientConditionResponse'] = _CLIENTCONDITIONRESPONSE

ClientCondition = _reflection.GeneratedProtocolMessageType('ClientCondition', (_message.Message,), dict(

  Room = _reflection.GeneratedProtocolMessageType('Room', (_message.Message,), dict(

    OfflineEdited = _reflection.GeneratedProtocolMessageType('OfflineEdited', (_message.Message,), dict(
      DESCRIPTOR = _CLIENTCONDITION_ROOM_OFFLINEEDITED,
      __module__ = 'ClientCondition_pb2'
      # @@protoc_insertion_point(class_scope:proto.ClientCondition.Room.OfflineEdited)
      ))
    ,

    OfflineDeleted = _reflection.GeneratedProtocolMessageType('OfflineDeleted', (_message.Message,), dict(
      DESCRIPTOR = _CLIENTCONDITION_ROOM_OFFLINEDELETED,
      __module__ = 'ClientCondition_pb2'
      # @@protoc_insertion_point(class_scope:proto.ClientCondition.Room.OfflineDeleted)
      ))
    ,
    DESCRIPTOR = _CLIENTCONDITION_ROOM,
    __module__ = 'ClientCondition_pb2'
    # @@protoc_insertion_point(class_scope:proto.ClientCondition.Room)
    ))
  ,
  DESCRIPTOR = _CLIENTCONDITION,
  __module__ = 'ClientCondition_pb2'
  # @@protoc_insertion_point(class_scope:proto.ClientCondition)
  ))
_sym_db.RegisterMessage(ClientCondition)
_sym_db.RegisterMessage(ClientCondition.Room)
_sym_db.RegisterMessage(ClientCondition.Room.OfflineEdited)
_sym_db.RegisterMessage(ClientCondition.Room.OfflineDeleted)

ClientConditionResponse = _reflection.GeneratedProtocolMessageType('ClientConditionResponse', (_message.Message,), dict(
  DESCRIPTOR = _CLIENTCONDITIONRESPONSE,
  __module__ = 'ClientCondition_pb2'
  # @@protoc_insertion_point(class_scope:proto.ClientConditionResponse)
  ))
_sym_db.RegisterMessage(ClientConditionResponse)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n\016net.iGap.protoB\024ProtoClientCondition'))
# @@protoc_insertion_point(module_scope)



import re
from typing import Optional, Union, List
from .message import Message

# class Filter:
#     async def check(self, message: Message) -> bool:
#         raise NotImplementedError

def maybe_instance(f):
    return f() if isinstance(f, type) else f


class FilterMeta(type):
    def __and__(cls, other):
        return AndFilter(maybe_instance(cls), maybe_instance(other))

    def __rand__(cls, other):
        return AndFilter(maybe_instance(other), maybe_instance(cls))

    def __or__(cls, other):
        return OrFilter(maybe_instance(cls), maybe_instance(other))

    def __ror__(cls, other):
        return OrFilter(maybe_instance(other), maybe_instance(cls))

    def __invert__(cls):
        return NotFilter(maybe_instance(cls))


class Filter(metaclass=FilterMeta):
    async def check(self, update):
        raise NotImplementedError

    async def __call__(self, message: Message) -> bool:
        return await self.check(message)

    def __and__(self, other):
        return AndFilter(maybe_instance(self), maybe_instance(other))

    def __rand__(self, other):
        return AndFilter(maybe_instance(other), maybe_instance(self))

    def __or__(self, other):
        return OrFilter(maybe_instance(self), maybe_instance(other))

    def __ror__(self, other):
        return OrFilter(maybe_instance(other), maybe_instance(self))

    def __invert__(self):
        instance = self() if isinstance(self, type) else self
        return NotFilter(instance)


class AndFilter(Filter):
    def __init__(self, *filters: Filter):
        self.filters = filters

    async def check(self, update: Message) -> bool:
        for f in self.filters:
            if isinstance(f, type):  # اگر کلاس دادیم
                f = f()
            if not await f.check(update):
                return False
        return True


class OrFilter(Filter):
    def __init__(self, *filters: Filter):
        self.filters = filters

    async def check(self, update):
        for f in self.filters:
            if isinstance(f, type):
                f = f()
            if await f.check(update):
                return True
        return False


class NotFilter(Filter):
    def __init__(self, f: Filter):
        self.f = f if not isinstance(f, type) else f()

    async def check(self, update):
        return not await self.f.check(update)



class text(Filter):
    """
    Filter برای بررسی محتوای متنی پیام.

    این فیلتر می‌تواند پیام‌ها را بر اساس:
    - وجود هر متن (اگر هیچ مقداری داده نشود).
    - یک رشته‌ی دقیق.
    - یک الگوی regex.

    Args:
        text (str, optional): رشته‌ی دقیق یا الگوی regex برای match.
        regex (bool): اگر True باشد، `text` به عنوان regex استفاده می‌شود.

    Returns:
        bool: اگر متن پیام با معیار داده شده match کند، True برمی‌گرداند.
    """

    def __init__(self, text: Optional[str] = None, regex: bool = False):
        self.text = text
        self.regex = regex
        self._compiled = re.compile(text) if regex and text else None

    async def check(self, message: Message) -> bool:
        msg_text = message.room_message.message
        if not msg_text:
            return False

        if not self.text:
            return True

        if self.regex and self._compiled:
            return bool(self._compiled.match(msg_text))

        return msg_text == self.text

class commands(Filter):
    """
    Advanced filter for detecting bot commands (e.g. /start, !help, test).

    Features:
        - Supports multiple command prefixes (default: / and !).
        - Case-insensitive option.
        - Matches both exact commands and commands with arguments.
        - Supports single or multiple commands.

    Args:
        commands (Union[str, List[str]]): Command or list of commands (without prefix).
        prefixes (List[str], optional): Allowed prefixes (default: ["/", "!"]).
        case_sensitive (bool, optional): Whether command matching is case-sensitive. Default False.
        allow_no_prefix (bool, optional): If True, matches commands even without prefix. Default False.

    Example:
        >>> @bot.on_message(commands("start"))
        ... async def handle_start(msg: Message):
        ...     await msg.reply("Welcome to the bot!")

        >>> @bot.on_message(commands(["help", "about"], prefixes=["/", ".", "!"]))
        ... async def handle_help(msg: Message):
        ...     await msg.reply("Help/About detected!")

        >>> @bot.on_message(commands("test", allow_no_prefix=True))
        ... async def handle_test(msg: Message):
        ...     await msg.reply("Matched with or without prefix")
    """

    def __init__(
        self,
        commands: Union[str, List[str]],
        prefixes: List[str] = ["/"],
        case_sensitive: bool = False,
        allow_no_prefix: bool = False,
    ):
        self.commands = [commands] if isinstance(commands, str) else commands
        self.prefixes = prefixes
        self.case_sensitive = case_sensitive
        self.allow_no_prefix = allow_no_prefix

        if not case_sensitive:
            self.commands = [cmd.lower() for cmd in self.commands]

    async def check(self, message: Message) -> bool:
        # گرفتن متن پیام از ساختار اصلی
        msg_text = message.room_message.message
        if not msg_text:
            return False

        # آماده‌سازی متن برای مقایسه
        check_text = msg_text if self.case_sensitive else msg_text.lower()

        # جدا کردن دستور از آرگومان‌ها
        parts = check_text.split(maxsplit=1)
        command_part = parts[0]

        # بررسی با prefixها
        for cmd in self.commands:
            for prefix in self.prefixes:
                if command_part == f"{prefix}{cmd}" or command_part.startswith(f"{prefix}{cmd}"):
                    return True

            # اجازه‌ی match بدون prefix
            if self.allow_no_prefix and (command_part == cmd or command_part.startswith(cmd)):
                return True

        return False

class room_id(Filter):
    def __init__(self, room_id: Union[List[str], str]):
        self.room_ids = [room_id] if isinstance(room_id, str) else room_id
    
    async def check(self, message: Message) -> bool:
        return message.room_id in self.room_ids

class private(Filter):
    def __init__(self, add_action_ids: List[str] =None):
        self.private_action_ids = (add_action_ids or []) + [str(i) for i in range(200, 210)] + [str(i) for i in range(30200, 30210)]

    async def check(self, message: Message) -> bool:
        return message.action_id in self.private_action_ids

class group(Filter):
    def __init__(self, add_action_ids: List[str] =None):
        self.group_action_ids = (add_action_ids or []) + [str(i) for i in range(300, 329)] + [str(i) for i in range(30300, 30329)]

    async def check(self, message: Message) -> bool:
        return message.action_id in self.group_action_ids

class channel(Filter):
    def __init__(self, add_action_ids: List[str] =None):
        self.channel_action_ids = (add_action_ids or []) + [str(i) for i in range(400, 427)] + [str(i) for i in range(30400, 30427)]

    async def check(self, message: Message) -> bool:
        return message.action_id in self.channel_action_ids

class action_id():
    def __init__(self, action_ids: List[str]):
        self.action_ids = action_ids
    async def check(self, message: Message) -> bool:
        return message.action_id in self.action_ids

# class Filters:
#     @staticmethod
#     def text(message: Message) -> bool:
#         """فیلتر پیام‌های متنی"""
#         return bool(message.text and message.text.strip())

#     @staticmethod
#     def command(cmd: str) -> Callable[[Message], bool]:
#         """فیلتر برای دستور خاص مثل /start"""
#         def inner(message: Message) -> bool:
#             return bool(message.text and message.text.strip().startswith(f"/{cmd}"))
#         return inner

#     @staticmethod
#     def from_user(user_id: str) -> Callable[[Message], bool]:
#         """فیلتر برای پیام‌های یک کاربر خاص"""
#         def inner(message: Message) -> bool:
#             return str(message.room_message.author.user.user_id) == str(user_id)
#         return inner

#     # @staticmethod
#     # def has_attachment(message: Message) -> bool:
#     #     """فیلتر پیام‌هایی که فایل یا عکس دارند"""
#     #     return bool(message.attachment)

#     @staticmethod
#     def reply(message: Message) -> bool:
#         """فیلتر پیام‌هایی که به پیام دیگری ریپلای شده‌اند"""
#         return bool(message.room_message.reply_to)


from setuptools import setup, find_packages

setup(
    name="ighap-bot",
    version="0.1.1",
    description="Unofficial iGap Bot API client for Python",
    long_description=open("README.md", encoding="utf-8").read(),
    long_description_content_type="text/markdown",
    author="Ehsan",
    author_email="Botkaplus@gmail.com",
    url="https://github.com/sinyor-ehsan/ighap-bot",
    packages=find_packages(),
    install_requires=[
        "protobuf>=3.19.0,<4.0.0",
        "aiohttp>=3.8.0",
        "Pillow>=9.0.0"
    ],
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires=">=3.8",
)


# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ClientSearchRoomHistory.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ighap_bot.proto import Request_pb2 as Request__pb2
from ighap_bot.proto import Response_pb2 as Response__pb2
from ighap_bot.proto import Global_pb2 as Global__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='ClientSearchRoomHistory.proto',
  package='proto',
  syntax='proto3',
  serialized_pb=_b('\n\x1d\x43lientSearchRoomHistory.proto\x12\x05proto\x1a\rRequest.proto\x1a\x0eResponse.proto\x1a\x0cGlobal.proto\"\xff\x01\n\x17\x43lientSearchRoomHistory\x12\x1f\n\x07request\x18\x01 \x01(\x0b\x32\x0e.proto.Request\x12\x0f\n\x07room_id\x18\x02 \x01(\x04\x12\x0e\n\x06offset\x18\x03 \x01(\r\x12\x35\n\x06\x66ilter\x18\x04 \x01(\x0e\x32%.proto.ClientSearchRoomHistory.Filter\x12\x19\n\x11offset_message_id\x18\x05 \x01(\x04\"P\n\x06\x46ilter\x12\t\n\x05IMAGE\x10\x00\x12\t\n\x05VIDEO\x10\x01\x12\t\n\x05\x41UDIO\x10\x02\x12\t\n\x05VOICE\x10\x03\x12\x07\n\x03GIF\x10\x04\x12\x08\n\x04\x46ILE\x10\x05\x12\x07\n\x03URL\x10\x06\"\x95\x01\n\x1f\x43lientSearchRoomHistoryResponse\x12!\n\x08response\x18\x01 \x01(\x0b\x32\x0f.proto.Response\x12\x12\n\ntotalCount\x18\x02 \x01(\r\x12\x17\n\x0fnotDeletedCount\x18\x03 \x01(\r\x12\"\n\x06result\x18\x04 \x03(\x0b\x32\x12.proto.RoomMessageB.\n\x0enet.iGap.protoB\x1cProtoClientSearchRoomHistoryb\x06proto3')
  ,
  dependencies=[Request__pb2.DESCRIPTOR,Response__pb2.DESCRIPTOR,Global__pb2.DESCRIPTOR,])
_sym_db.RegisterFileDescriptor(DESCRIPTOR)



_CLIENTSEARCHROOMHISTORY_FILTER = _descriptor.EnumDescriptor(
  name='Filter',
  full_name='proto.ClientSearchRoomHistory.Filter',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='IMAGE', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='VIDEO', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='AUDIO', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='VOICE', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GIF', index=4, number=4,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FILE', index=5, number=5,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='URL', index=6, number=6,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=261,
  serialized_end=341,
)
_sym_db.RegisterEnumDescriptor(_CLIENTSEARCHROOMHISTORY_FILTER)


_CLIENTSEARCHROOMHISTORY = _descriptor.Descriptor(
  name='ClientSearchRoomHistory',
  full_name='proto.ClientSearchRoomHistory',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='request', full_name='proto.ClientSearchRoomHistory.request', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='room_id', full_name='proto.ClientSearchRoomHistory.room_id', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='offset', full_name='proto.ClientSearchRoomHistory.offset', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='filter', full_name='proto.ClientSearchRoomHistory.filter', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='offset_message_id', full_name='proto.ClientSearchRoomHistory.offset_message_id', index=4,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CLIENTSEARCHROOMHISTORY_FILTER,
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=86,
  serialized_end=341,
)


_CLIENTSEARCHROOMHISTORYRESPONSE = _descriptor.Descriptor(
  name='ClientSearchRoomHistoryResponse',
  full_name='proto.ClientSearchRoomHistoryResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='response', full_name='proto.ClientSearchRoomHistoryResponse.response', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='totalCount', full_name='proto.ClientSearchRoomHistoryResponse.totalCount', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='notDeletedCount', full_name='proto.ClientSearchRoomHistoryResponse.notDeletedCount', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='result', full_name='proto.ClientSearchRoomHistoryResponse.result', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=344,
  serialized_end=493,
)

_CLIENTSEARCHROOMHISTORY.fields_by_name['request'].message_type = Request__pb2._REQUEST
_CLIENTSEARCHROOMHISTORY.fields_by_name['filter'].enum_type = _CLIENTSEARCHROOMHISTORY_FILTER
_CLIENTSEARCHROOMHISTORY_FILTER.containing_type = _CLIENTSEARCHROOMHISTORY
_CLIENTSEARCHROOMHISTORYRESPONSE.fields_by_name['response'].message_type = Response__pb2._RESPONSE
_CLIENTSEARCHROOMHISTORYRESPONSE.fields_by_name['result'].message_type = Global__pb2._ROOMMESSAGE
DESCRIPTOR.message_types_by_name['ClientSearchRoomHistory'] = _CLIENTSEARCHROOMHISTORY
DESCRIPTOR.message_types_by_name['ClientSearchRoomHistoryResponse'] = _CLIENTSEARCHROOMHISTORYRESPONSE

ClientSearchRoomHistory = _reflection.GeneratedProtocolMessageType('ClientSearchRoomHistory', (_message.Message,), dict(
  DESCRIPTOR = _CLIENTSEARCHROOMHISTORY,
  __module__ = 'ClientSearchRoomHistory_pb2'
  # @@protoc_insertion_point(class_scope:proto.ClientSearchRoomHistory)
  ))
_sym_db.RegisterMessage(ClientSearchRoomHistory)

ClientSearchRoomHistoryResponse = _reflection.GeneratedProtocolMessageType('ClientSearchRoomHistoryResponse', (_message.Message,), dict(
  DESCRIPTOR = _CLIENTSEARCHROOMHISTORYRESPONSE,
  __module__ = 'ClientSearchRoomHistory_pb2'
  # @@protoc_insertion_point(class_scope:proto.ClientSearchRoomHistoryResponse)
  ))
_sym_db.RegisterMessage(ClientSearchRoomHistoryResponse)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n\016net.iGap.protoB\034ProtoClientSearchRoomHistory'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ConnectionSecuring.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ighap_bot.proto import Request_pb2 as Request__pb2
from ighap_bot.proto import Response_pb2 as Response__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='ConnectionSecuring.proto',
  package='proto',
  syntax='proto3',
  serialized_pb=_b('\n\x18\x43onnectionSecuring.proto\x12\x05proto\x1a\rRequest.proto\x1a\x0eResponse.proto\"\xc6\x01\n\x1a\x43onnectionSecuringResponse\x12!\n\x08response\x18\x01 \x01(\x0b\x32\x0f.proto.Response\x12\x12\n\npublic_key\x18\x02 \x01(\t\x12\x1c\n\x14symmetric_key_length\x18\x03 \x01(\r\x12\x1a\n\x12heartbeat_interval\x18\x04 \x01(\r\x12\x19\n\x11primary_node_name\x18\x05 \x01(\t\x12\x1c\n\x14secondary_chunk_size\x18\x06 \x01(\r\"a\n\x16\x43onnectionSymmetricKey\x12\x1f\n\x07request\x18\x01 \x01(\x0b\x32\x0e.proto.Request\x12\x15\n\rsymmetric_key\x18\x02 \x01(\x0c\x12\x0f\n\x07version\x18\x03 \x01(\r\"\xf4\x01\n\x1e\x43onnectionSymmetricKeyResponse\x12!\n\x08response\x18\x01 \x01(\x0b\x32\x0f.proto.Response\x12<\n\x06status\x18\x02 \x01(\x0e\x32,.proto.ConnectionSymmetricKeyResponse.Status\x12\x18\n\x10symmetric_method\x18\x03 \x01(\t\x12\x19\n\x11symmetric_iv_size\x18\x04 \x01(\r\x12\x16\n\x0esecurity_issue\x18\x05 \x01(\x08\"$\n\x06Status\x12\x0c\n\x08REJECTED\x10\x00\x12\x0c\n\x08\x41\x43\x43\x45PTED\x10\x01\x42)\n\x0enet.iGap.protoB\x17ProtoConnectionSecuringb\x06proto3')
  ,
  dependencies=[Request__pb2.DESCRIPTOR,Response__pb2.DESCRIPTOR,])
_sym_db.RegisterFileDescriptor(DESCRIPTOR)



_CONNECTIONSYMMETRICKEYRESPONSE_STATUS = _descriptor.EnumDescriptor(
  name='Status',
  full_name='proto.ConnectionSymmetricKeyResponse.Status',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='REJECTED', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ACCEPTED', index=1, number=1,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=575,
  serialized_end=611,
)
_sym_db.RegisterEnumDescriptor(_CONNECTIONSYMMETRICKEYRESPONSE_STATUS)


_CONNECTIONSECURINGRESPONSE = _descriptor.Descriptor(
  name='ConnectionSecuringResponse',
  full_name='proto.ConnectionSecuringResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='response', full_name='proto.ConnectionSecuringResponse.response', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='public_key', full_name='proto.ConnectionSecuringResponse.public_key', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='symmetric_key_length', full_name='proto.ConnectionSecuringResponse.symmetric_key_length', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='heartbeat_interval', full_name='proto.ConnectionSecuringResponse.heartbeat_interval', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='primary_node_name', full_name='proto.ConnectionSecuringResponse.primary_node_name', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='secondary_chunk_size', full_name='proto.ConnectionSecuringResponse.secondary_chunk_size', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=67,
  serialized_end=265,
)


_CONNECTIONSYMMETRICKEY = _descriptor.Descriptor(
  name='ConnectionSymmetricKey',
  full_name='proto.ConnectionSymmetricKey',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='request', full_name='proto.ConnectionSymmetricKey.request', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='symmetric_key', full_name='proto.ConnectionSymmetricKey.symmetric_key', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='version', full_name='proto.ConnectionSymmetricKey.version', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=267,
  serialized_end=364,
)


_CONNECTIONSYMMETRICKEYRESPONSE = _descriptor.Descriptor(
  name='ConnectionSymmetricKeyResponse',
  full_name='proto.ConnectionSymmetricKeyResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='response', full_name='proto.ConnectionSymmetricKeyResponse.response', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='status', full_name='proto.ConnectionSymmetricKeyResponse.status', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='symmetric_method', full_name='proto.ConnectionSymmetricKeyResponse.symmetric_method', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='symmetric_iv_size', full_name='proto.ConnectionSymmetricKeyResponse.symmetric_iv_size', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='security_issue', full_name='proto.ConnectionSymmetricKeyResponse.security_issue', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CONNECTIONSYMMETRICKEYRESPONSE_STATUS,
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=367,
  serialized_end=611,
)

_CONNECTIONSECURINGRESPONSE.fields_by_name['response'].message_type = Response__pb2._RESPONSE
_CONNECTIONSYMMETRICKEY.fields_by_name['request'].message_type = Request__pb2._REQUEST
_CONNECTIONSYMMETRICKEYRESPONSE.fields_by_name['response'].message_type = Response__pb2._RESPONSE
_CONNECTIONSYMMETRICKEYRESPONSE.fields_by_name['status'].enum_type = _CONNECTIONSYMMETRICKEYRESPONSE_STATUS
_CONNECTIONSYMMETRICKEYRESPONSE_STATUS.containing_type = _CONNECTIONSYMMETRICKEYRESPONSE
DESCRIPTOR.message_types_by_name['ConnectionSecuringResponse'] = _CONNECTIONSECURINGRESPONSE
DESCRIPTOR.message_types_by_name['ConnectionSymmetricKey'] = _CONNECTIONSYMMETRICKEY
DESCRIPTOR.message_types_by_name['ConnectionSymmetricKeyResponse'] = _CONNECTIONSYMMETRICKEYRESPONSE

ConnectionSecuringResponse = _reflection.GeneratedProtocolMessageType('ConnectionSecuringResponse', (_message.Message,), dict(
  DESCRIPTOR = _CONNECTIONSECURINGRESPONSE,
  __module__ = 'ConnectionSecuring_pb2'
  # @@protoc_insertion_point(class_scope:proto.ConnectionSecuringResponse)
  ))
_sym_db.RegisterMessage(ConnectionSecuringResponse)

ConnectionSymmetricKey = _reflection.GeneratedProtocolMessageType('ConnectionSymmetricKey', (_message.Message,), dict(
  DESCRIPTOR = _CONNECTIONSYMMETRICKEY,
  __module__ = 'ConnectionSecuring_pb2'
  # @@protoc_insertion_point(class_scope:proto.ConnectionSymmetricKey)
  ))
_sym_db.RegisterMessage(ConnectionSymmetricKey)

ConnectionSymmetricKeyResponse = _reflection.GeneratedProtocolMessageType('ConnectionSymmetricKeyResponse', (_message.Message,), dict(
  DESCRIPTOR = _CONNECTIONSYMMETRICKEYRESPONSE,
  __module__ = 'ConnectionSecuring_pb2'
  # @@protoc_insertion_point(class_scope:proto.ConnectionSymmetricKeyResponse)
  ))
_sym_db.RegisterMessage(ConnectionSymmetricKeyResponse)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n\016net.iGap.protoB\027ProtoConnectionSecuring'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: GeoGetRegisterStatus.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ighap_bot.proto import Request_pb2 as Request__pb2
from ighap_bot.proto import Response_pb2 as Response__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='GeoGetRegisterStatus.proto',
  package='proto',
  syntax='proto3',
  serialized_pb=_b('\n\x1aGeoGetRegisterStatus.proto\x12\x05proto\x1a\rRequest.proto\x1a\x0eResponse.proto\"7\n\x14GeoGetRegisterStatus\x12\x1f\n\x07request\x18\x01 \x01(\x0b\x32\x0e.proto.Request\"Q\n\x1cGeoGetRegisterStatusResponse\x12!\n\x08response\x18\x01 \x01(\x0b\x32\x0f.proto.Response\x12\x0e\n\x06\x65nable\x18\x02 \x01(\x08\x42+\n\x0enet.iGap.protoB\x19ProtoGeoGetRegisterStatusb\x06proto3')
  ,
  dependencies=[Request__pb2.DESCRIPTOR,Response__pb2.DESCRIPTOR,])
_sym_db.RegisterFileDescriptor(DESCRIPTOR)




_GEOGETREGISTERSTATUS = _descriptor.Descriptor(
  name='GeoGetRegisterStatus',
  full_name='proto.GeoGetRegisterStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='request', full_name='proto.GeoGetRegisterStatus.request', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=68,
  serialized_end=123,
)


_GEOGETREGISTERSTATUSRESPONSE = _descriptor.Descriptor(
  name='GeoGetRegisterStatusResponse',
  full_name='proto.GeoGetRegisterStatusResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='response', full_name='proto.GeoGetRegisterStatusResponse.response', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='enable', full_name='proto.GeoGetRegisterStatusResponse.enable', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=125,
  serialized_end=206,
)

_GEOGETREGISTERSTATUS.fields_by_name['request'].message_type = Request__pb2._REQUEST
_GEOGETREGISTERSTATUSRESPONSE.fields_by_name['response'].message_type = Response__pb2._RESPONSE
DESCRIPTOR.message_types_by_name['GeoGetRegisterStatus'] = _GEOGETREGISTERSTATUS
DESCRIPTOR.message_types_by_name['GeoGetRegisterStatusResponse'] = _GEOGETREGISTERSTATUSRESPONSE

GeoGetRegisterStatus = _reflection.GeneratedProtocolMessageType('GeoGetRegisterStatus', (_message.Message,), dict(
  DESCRIPTOR = _GEOGETREGISTERSTATUS,
  __module__ = 'GeoGetRegisterStatus_pb2'
  # @@protoc_insertion_point(class_scope:proto.GeoGetRegisterStatus)
  ))
_sym_db.RegisterMessage(GeoGetRegisterStatus)

GeoGetRegisterStatusResponse = _reflection.GeneratedProtocolMessageType('GeoGetRegisterStatusResponse', (_message.Message,), dict(
  DESCRIPTOR = _GEOGETREGISTERSTATUSRESPONSE,
  __module__ = 'GeoGetRegisterStatus_pb2'
  # @@protoc_insertion_point(class_scope:proto.GeoGetRegisterStatusResponse)
  ))
_sym_db.RegisterMessage(GeoGetRegisterStatusResponse)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n\016net.iGap.protoB\031ProtoGeoGetRegisterStatus'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ClientRegisterDevice.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ighap_bot.proto import Request_pb2 as Request__pb2
from ighap_bot.proto import Response_pb2 as Response__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='ClientRegisterDevice.proto',
  package='proto',
  syntax='proto3',
  serialized_pb=_b('\n\x1a\x43lientRegisterDevice.proto\x12\x05proto\x1a\rRequest.proto\x1a\x0eResponse.proto\"\xaa\x01\n\x14\x43lientRegisterDevice\x12\x1f\n\x07request\x18\x01 \x01(\x0b\x32\x0e.proto.Request\x12\r\n\x05token\x18\x02 \x01(\t\x12.\n\x04type\x18\x03 \x01(\x0e\x32 .proto.ClientRegisterDevice.Type\"2\n\x04Type\x12\x0b\n\x07GENERIC\x10\x00\x12\x0b\n\x07\x41NDROID\x10\x01\x12\x07\n\x03IOS\x10\x02\x12\x07\n\x03WEB\x10\x03\"A\n\x1c\x43lientRegisterDeviceResponse\x12!\n\x08response\x18\x01 \x01(\x0b\x32\x0f.proto.ResponseB+\n\x0enet.iGap.protoB\x19ProtoClientRegisterDeviceb\x06proto3')
  ,
  dependencies=[Request__pb2.DESCRIPTOR,Response__pb2.DESCRIPTOR,])
_sym_db.RegisterFileDescriptor(DESCRIPTOR)



_CLIENTREGISTERDEVICE_TYPE = _descriptor.EnumDescriptor(
  name='Type',
  full_name='proto.ClientRegisterDevice.Type',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='GENERIC', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ANDROID', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='IOS', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='WEB', index=3, number=3,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=189,
  serialized_end=239,
)
_sym_db.RegisterEnumDescriptor(_CLIENTREGISTERDEVICE_TYPE)


_CLIENTREGISTERDEVICE = _descriptor.Descriptor(
  name='ClientRegisterDevice',
  full_name='proto.ClientRegisterDevice',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='request', full_name='proto.ClientRegisterDevice.request', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='token', full_name='proto.ClientRegisterDevice.token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='type', full_name='proto.ClientRegisterDevice.type', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CLIENTREGISTERDEVICE_TYPE,
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=69,
  serialized_end=239,
)


_CLIENTREGISTERDEVICERESPONSE = _descriptor.Descriptor(
  name='ClientRegisterDeviceResponse',
  full_name='proto.ClientRegisterDeviceResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='response', full_name='proto.ClientRegisterDeviceResponse.response', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=241,
  serialized_end=306,
)

_CLIENTREGISTERDEVICE.fields_by_name['request'].message_type = Request__pb2._REQUEST
_CLIENTREGISTERDEVICE.fields_by_name['type'].enum_type = _CLIENTREGISTERDEVICE_TYPE
_CLIENTREGISTERDEVICE_TYPE.containing_type = _CLIENTREGISTERDEVICE
_CLIENTREGISTERDEVICERESPONSE.fields_by_name['response'].message_type = Response__pb2._RESPONSE
DESCRIPTOR.message_types_by_name['ClientRegisterDevice'] = _CLIENTREGISTERDEVICE
DESCRIPTOR.message_types_by_name['ClientRegisterDeviceResponse'] = _CLIENTREGISTERDEVICERESPONSE

ClientRegisterDevice = _reflection.GeneratedProtocolMessageType('ClientRegisterDevice', (_message.Message,), dict(
  DESCRIPTOR = _CLIENTREGISTERDEVICE,
  __module__ = 'ClientRegisterDevice_pb2'
  # @@protoc_insertion_point(class_scope:proto.ClientRegisterDevice)
  ))
_sym_db.RegisterMessage(ClientRegisterDevice)

ClientRegisterDeviceResponse = _reflection.GeneratedProtocolMessageType('ClientRegisterDeviceResponse', (_message.Message,), dict(
  DESCRIPTOR = _CLIENTREGISTERDEVICERESPONSE,
  __module__ = 'ClientRegisterDevice_pb2'
  # @@protoc_insertion_point(class_scope:proto.ClientRegisterDeviceResponse)
  ))
_sym_db.RegisterMessage(ClientRegisterDeviceResponse)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n\016net.iGap.protoB\031ProtoClientRegisterDevice'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: UserReport.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ighap_bot.proto import Request_pb2 as Request__pb2
from ighap_bot.proto import Response_pb2 as Response__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='UserReport.proto',
  package='proto',
  syntax='proto3',
  serialized_pb=_b('\n\x10UserReport.proto\x12\x05proto\x1a\rRequest.proto\x1a\x0eResponse.proto\"\xb9\x01\n\nUserReport\x12\x1f\n\x07request\x18\x01 \x01(\x0b\x32\x0e.proto.Request\x12\x0f\n\x07user_id\x18\x02 \x01(\x04\x12(\n\x06reason\x18\x03 \x01(\x0e\x32\x18.proto.UserReport.Reason\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\":\n\x06Reason\x12\t\n\x05OTHER\x10\x00\x12\x08\n\x04SPAM\x10\x01\x12\t\n\x05\x41\x42USE\x10\x02\x12\x10\n\x0c\x46\x41KE_ACCOUNT\x10\x03\"7\n\x12UserReportResponse\x12!\n\x08response\x18\x01 \x01(\x0b\x32\x0f.proto.ResponseB!\n\x0enet.iGap.protoB\x0fProtoUserReportb\x06proto3')
  ,
  dependencies=[Request__pb2.DESCRIPTOR,Response__pb2.DESCRIPTOR,])
_sym_db.RegisterFileDescriptor(DESCRIPTOR)



_USERREPORT_REASON = _descriptor.EnumDescriptor(
  name='Reason',
  full_name='proto.UserReport.Reason',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='OTHER', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SPAM', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ABUSE', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FAKE_ACCOUNT', index=3, number=3,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=186,
  serialized_end=244,
)
_sym_db.RegisterEnumDescriptor(_USERREPORT_REASON)


_USERREPORT = _descriptor.Descriptor(
  name='UserReport',
  full_name='proto.UserReport',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='request', full_name='proto.UserReport.request', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='user_id', full_name='proto.UserReport.user_id', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='reason', full_name='proto.UserReport.reason', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='description', full_name='proto.UserReport.description', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _USERREPORT_REASON,
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=59,
  serialized_end=244,
)


_USERREPORTRESPONSE = _descriptor.Descriptor(
  name='UserReportResponse',
  full_name='proto.UserReportResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='response', full_name='proto.UserReportResponse.response', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=246,
  serialized_end=301,
)

_USERREPORT.fields_by_name['request'].message_type = Request__pb2._REQUEST
_USERREPORT.fields_by_name['reason'].enum_type = _USERREPORT_REASON
_USERREPORT_REASON.containing_type = _USERREPORT
_USERREPORTRESPONSE.fields_by_name['response'].message_type = Response__pb2._RESPONSE
DESCRIPTOR.message_types_by_name['UserReport'] = _USERREPORT
DESCRIPTOR.message_types_by_name['UserReportResponse'] = _USERREPORTRESPONSE

UserReport = _reflection.GeneratedProtocolMessageType('UserReport', (_message.Message,), dict(
  DESCRIPTOR = _USERREPORT,
  __module__ = 'UserReport_pb2'
  # @@protoc_insertion_point(class_scope:proto.UserReport)
  ))
_sym_db.RegisterMessage(UserReport)

UserReportResponse = _reflection.GeneratedProtocolMessageType('UserReportResponse', (_message.Message,), dict(
  DESCRIPTOR = _USERREPORTRESPONSE,
  __module__ = 'UserReport_pb2'
  # @@protoc_insertion_point(class_scope:proto.UserReportResponse)
  ))
_sym_db.RegisterMessage(UserReportResponse)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n\016net.iGap.protoB\017ProtoUserReport'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: GroupChangeMemberRights.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ighap_bot.proto import Request_pb2 as Request__pb2
from ighap_bot.proto import Response_pb2 as Response__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='GroupChangeMemberRights.proto',
  package='proto',
  syntax='proto3',
  serialized_pb=_b('\n\x1dGroupChangeMemberRights.proto\x12\x05proto\x1a\rRequest.proto\x1a\x0eResponse.proto\"\xcd\x02\n\x17GroupChangeMemberRights\x12\x1f\n\x07request\x18\x01 \x01(\x0b\x32\x0e.proto.Request\x12\x0f\n\x07room_id\x18\x02 \x01(\x04\x12\x0f\n\x07user_id\x18\x03 \x01(\x04\x12?\n\npermission\x18\x04 \x01(\x0b\x32+.proto.GroupChangeMemberRights.MemberRights\x1a\xad\x01\n\x0cMemberRights\x12\x11\n\tsend_text\x18\x01 \x01(\x08\x12\x12\n\nsend_media\x18\x03 \x01(\x08\x12\x10\n\x08send_gif\x18\x04 \x01(\x08\x12\x14\n\x0csend_sticker\x18\x05 \x01(\x08\x12\x11\n\tsend_link\x18\x06 \x01(\x08\x12\x13\n\x0bpin_message\x18\x07 \x01(\x08\x12\x12\n\nadd_member\x18\x08 \x01(\x08\x12\x12\n\nget_member\x18\t \x01(\x08\"\xa7\x01\n\x1fGroupChangeMemberRightsResponse\x12!\n\x08response\x18\x01 \x01(\x0b\x32\x0f.proto.Response\x12\x0f\n\x07room_id\x18\x02 \x01(\x04\x12\x0f\n\x07user_id\x18\x03 \x01(\x04\x12?\n\npermission\x18\x04 \x01(\x0b\x32+.proto.GroupChangeMemberRights.MemberRightsB.\n\x0enet.iGap.protoB\x1cProtoGroupChangeMemberRightsb\x06proto3')
  ,
  dependencies=[Request__pb2.DESCRIPTOR,Response__pb2.DESCRIPTOR,])
_sym_db.RegisterFileDescriptor(DESCRIPTOR)




_GROUPCHANGEMEMBERRIGHTS_MEMBERRIGHTS = _descriptor.Descriptor(
  name='MemberRights',
  full_name='proto.GroupChangeMemberRights.MemberRights',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='send_text', full_name='proto.GroupChangeMemberRights.MemberRights.send_text', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='send_media', full_name='proto.GroupChangeMemberRights.MemberRights.send_media', index=1,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='send_gif', full_name='proto.GroupChangeMemberRights.MemberRights.send_gif', index=2,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='send_sticker', full_name='proto.GroupChangeMemberRights.MemberRights.send_sticker', index=3,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='send_link', full_name='proto.GroupChangeMemberRights.MemberRights.send_link', index=4,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='pin_message', full_name='proto.GroupChangeMemberRights.MemberRights.pin_message', index=5,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='add_member', full_name='proto.GroupChangeMemberRights.MemberRights.add_member', index=6,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='get_member', full_name='proto.GroupChangeMemberRights.MemberRights.get_member', index=7,
      number=9, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=232,
  serialized_end=405,
)

_GROUPCHANGEMEMBERRIGHTS = _descriptor.Descriptor(
  name='GroupChangeMemberRights',
  full_name='proto.GroupChangeMemberRights',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='request', full_name='proto.GroupChangeMemberRights.request', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='room_id', full_name='proto.GroupChangeMemberRights.room_id', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='user_id', full_name='proto.GroupChangeMemberRights.user_id', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='permission', full_name='proto.GroupChangeMemberRights.permission', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_GROUPCHANGEMEMBERRIGHTS_MEMBERRIGHTS, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=72,
  serialized_end=405,
)


_GROUPCHANGEMEMBERRIGHTSRESPONSE = _descriptor.Descriptor(
  name='GroupChangeMemberRightsResponse',
  full_name='proto.GroupChangeMemberRightsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='response', full_name='proto.GroupChangeMemberRightsResponse.response', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='room_id', full_name='proto.GroupChangeMemberRightsResponse.room_id', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='user_id', full_name='proto.GroupChangeMemberRightsResponse.user_id', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='permission', full_name='proto.GroupChangeMemberRightsResponse.permission', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=408,
  serialized_end=575,
)

_GROUPCHANGEMEMBERRIGHTS_MEMBERRIGHTS.containing_type = _GROUPCHANGEMEMBERRIGHTS
_GROUPCHANGEMEMBERRIGHTS.fields_by_name['request'].message_type = Request__pb2._REQUEST
_GROUPCHANGEMEMBERRIGHTS.fields_by_name['permission'].message_type = _GROUPCHANGEMEMBERRIGHTS_MEMBERRIGHTS
_GROUPCHANGEMEMBERRIGHTSRESPONSE.fields_by_name['response'].message_type = Response__pb2._RESPONSE
_GROUPCHANGEMEMBERRIGHTSRESPONSE.fields_by_name['permission'].message_type = _GROUPCHANGEMEMBERRIGHTS_MEMBERRIGHTS
DESCRIPTOR.message_types_by_name['GroupChangeMemberRights'] = _GROUPCHANGEMEMBERRIGHTS
DESCRIPTOR.message_types_by_name['GroupChangeMemberRightsResponse'] = _GROUPCHANGEMEMBERRIGHTSRESPONSE

GroupChangeMemberRights = _reflection.GeneratedProtocolMessageType('GroupChangeMemberRights', (_message.Message,), dict(

  MemberRights = _reflection.GeneratedProtocolMessageType('MemberRights', (_message.Message,), dict(
    DESCRIPTOR = _GROUPCHANGEMEMBERRIGHTS_MEMBERRIGHTS,
    __module__ = 'GroupChangeMemberRights_pb2'
    # @@protoc_insertion_point(class_scope:proto.GroupChangeMemberRights.MemberRights)
    ))
  ,
  DESCRIPTOR = _GROUPCHANGEMEMBERRIGHTS,
  __module__ = 'GroupChangeMemberRights_pb2'
  # @@protoc_insertion_point(class_scope:proto.GroupChangeMemberRights)
  ))
_sym_db.RegisterMessage(GroupChangeMemberRights)
_sym_db.RegisterMessage(GroupChangeMemberRights.MemberRights)

GroupChangeMemberRightsResponse = _reflection.GeneratedProtocolMessageType('GroupChangeMemberRightsResponse', (_message.Message,), dict(
  DESCRIPTOR = _GROUPCHANGEMEMBERRIGHTSRESPONSE,
  __module__ = 'GroupChangeMemberRights_pb2'
  # @@protoc_insertion_point(class_scope:proto.GroupChangeMemberRightsResponse)
  ))
_sym_db.RegisterMessage(GroupChangeMemberRightsResponse)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n\016net.iGap.protoB\034ProtoGroupChangeMemberRights'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ClientGetDiscovery.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ighap_bot.proto import Request_pb2 as Request__pb2
from ighap_bot.proto import Response_pb2 as Response__pb2
from ighap_bot.proto import Global_pb2 as Global__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='ClientGetDiscovery.proto',
  package='proto',
  syntax='proto3',
  serialized_pb=_b('\n\x18\x43lientGetDiscovery.proto\x12\x05proto\x1a\rRequest.proto\x1a\x0eResponse.proto\x1a\x0cGlobal.proto\"k\n\x12\x43lientGetDiscovery\x12\x1f\n\x07request\x18\x01 \x01(\x0b\x32\x0e.proto.Request\x12\x0f\n\x07page_id\x18\x02 \x01(\r\x12\x12\n\nproject_id\x18\x03 \x01(\r\x12\x0f\n\x07item_id\x18\x04 \x01(\r\"u\n\x1a\x43lientGetDiscoveryResponse\x12!\n\x08response\x18\x01 \x01(\x0b\x32\x0f.proto.Response\x12\r\n\x05title\x18\x02 \x01(\t\x12%\n\x0b\x64iscoveries\x18\x03 \x03(\x0b\x32\x10.proto.DiscoveryB)\n\x0enet.iGap.protoB\x17ProtoClientGetDiscoveryb\x06proto3')
  ,
  dependencies=[Request__pb2.DESCRIPTOR,Response__pb2.DESCRIPTOR,Global__pb2.DESCRIPTOR,])
_sym_db.RegisterFileDescriptor(DESCRIPTOR)




_CLIENTGETDISCOVERY = _descriptor.Descriptor(
  name='ClientGetDiscovery',
  full_name='proto.ClientGetDiscovery',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='request', full_name='proto.ClientGetDiscovery.request', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='page_id', full_name='proto.ClientGetDiscovery.page_id', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='project_id', full_name='proto.ClientGetDiscovery.project_id', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='item_id', full_name='proto.ClientGetDiscovery.item_id', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=80,
  serialized_end=187,
)


_CLIENTGETDISCOVERYRESPONSE = _descriptor.Descriptor(
  name='ClientGetDiscoveryResponse',
  full_name='proto.ClientGetDiscoveryResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='response', full_name='proto.ClientGetDiscoveryResponse.response', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='title', full_name='proto.ClientGetDiscoveryResponse.title', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='discoveries', full_name='proto.ClientGetDiscoveryResponse.discoveries', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=189,
  serialized_end=306,
)

_CLIENTGETDISCOVERY.fields_by_name['request'].message_type = Request__pb2._REQUEST
_CLIENTGETDISCOVERYRESPONSE.fields_by_name['response'].message_type = Response__pb2._RESPONSE
_CLIENTGETDISCOVERYRESPONSE.fields_by_name['discoveries'].message_type = Global__pb2._DISCOVERY
DESCRIPTOR.message_types_by_name['ClientGetDiscovery'] = _CLIENTGETDISCOVERY
DESCRIPTOR.message_types_by_name['ClientGetDiscoveryResponse'] = _CLIENTGETDISCOVERYRESPONSE

ClientGetDiscovery = _reflection.GeneratedProtocolMessageType('ClientGetDiscovery', (_message.Message,), dict(
  DESCRIPTOR = _CLIENTGETDISCOVERY,
  __module__ = 'ClientGetDiscovery_pb2'
  # @@protoc_insertion_point(class_scope:proto.ClientGetDiscovery)
  ))
_sym_db.RegisterMessage(ClientGetDiscovery)

ClientGetDiscoveryResponse = _reflection.GeneratedProtocolMessageType('ClientGetDiscoveryResponse', (_message.Message,), dict(
  DESCRIPTOR = _CLIENTGETDISCOVERYRESPONSE,
  __module__ = 'ClientGetDiscovery_pb2'
  # @@protoc_insertion_point(class_scope:proto.ClientGetDiscoveryResponse)
  ))
_sym_db.RegisterMessage(ClientGetDiscoveryResponse)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n\016net.iGap.protoB\027ProtoClientGetDiscovery'))
# @@protoc_insertion_point(module_scope)
